=== modified file 'drizzled/db.cc'
--- drizzled/db.cc	2008-11-06 23:30:06 +0000
+++ drizzled/db.cc	2008-11-13 06:47:49 +0000
@@ -957,8 +957,19 @@
       extension= strchr(file->name, '\0');
     if (find_type(extension, &deletable_extentions,1+2) <= 0)
     {
-      if (find_type(extension, ha_known_exts(),1+2) <= 0)
-	found_other_files++;
+      /*
+        ass ass ass.
+
+        strange checking for magic extensions that are then deleted if
+        not reg_ext (i.e. .frm).
+
+        and (previously) we'd err out on drop database if files not matching
+        engine ha_known_exts() or deletable_extensions were present.
+
+        presumably this was to avoid deleting other user data... except if that
+        data happened to be in files ending in .BAK, .opt or .TMD. *fun*
+       */
+      find_type(extension, ha_known_exts(),1+2);
       continue;
     }
     /* just for safety we use files_charset_info */

=== modified file 'drizzled/server_includes.h'
--- drizzled/server_includes.h	2008-11-13 02:56:15 +0000
+++ drizzled/server_includes.h	2008-11-13 06:47:49 +0000
@@ -631,6 +631,8 @@
 int create_frm(Session *session, const char *name, const char *db, const char *table,
                uint32_t reclength, unsigned char *fileinfo,
 	       HA_CREATE_INFO *create_info, uint32_t keys, KEY *key_info);
+int rename_table_proto_file(const char *from, const char* to);
+int delete_table_proto_file(char *file_name);
 int rename_file_ext(const char * from,const char * to,const char * ext);
 bool check_db_name(LEX_STRING *db);
 bool check_column_name(const char *name);

=== modified file 'drizzled/sql_base.cc'
--- drizzled/sql_base.cc	2008-11-06 23:30:06 +0000
+++ drizzled/sql_base.cc	2008-11-13 06:47:49 +0000
@@ -3857,6 +3857,8 @@
   handler *file;
   char *ext;
 
+  delete_table_proto_file(path);
+
   my_stpcpy(ext= strchr(path, '\0'), reg_ext);
   if (my_delete(path,MYF(0)))
     error=1; /* purecov: inspected */

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2008-11-13 06:44:11 +0000
+++ drizzled/sql_table.cc	2008-11-13 06:47:49 +0000
@@ -501,6 +501,11 @@
       if (!error || error == ENOENT || error == HA_ERR_NO_SUCH_TABLE)
       {
         int new_error;
+
+        /* for some weird-ass reason, we ignore the return code here
+           and things work. */
+        delete_table_proto_file(path);
+
         /* Delete the table definition file */
         my_stpcpy(end,reg_ext);
         if (!(new_error=my_delete(path,MYF(MY_WME))))
@@ -615,7 +620,11 @@
                                          db, table_name, reg_ext, flags);
   if (my_delete(path,MYF(0)))
     error= 1; /* purecov: inspected */
+
   path[path_length - reg_ext_length]= '\0'; // Remove reg_ext
+
+  error|= delete_table_proto_file(path);
+
   return(ha_delete_table(current_session, base, path, db, table_name, 0) ||
               error);
 }
@@ -2108,6 +2117,15 @@
       if (file)
         file->ha_rename_table(to_base, from_base);
     }
+
+    if(!(flags & NO_FRM_RENAME)
+       && rename_table_proto_file(from_base, to_base))
+    {
+      error= errno;
+      rename_file_ext(to, from, reg_ext);
+      if (file)
+        file->ha_rename_table(to_base, from_base);
+    }
   }
   delete file;
   if (error == HA_ERR_WRONG_COMMAND)

=== modified file 'drizzled/unireg.cc'
--- drizzled/unireg.cc	2008-11-09 02:15:03 +0000
+++ drizzled/unireg.cc	2008-11-13 06:47:49 +0000
@@ -500,6 +500,27 @@
     table_options->set_block_size(create_info->block_size);
 }
 
+int rename_table_proto_file(const char *from, const char* to)
+{
+  string from_path(from);
+  string to_path(to);
+  string file_ext = ".tabledefinition";
+
+  from_path.append(file_ext);
+  to_path.append(file_ext);
+
+  return my_rename(from_path.c_str(),to_path.c_str(),MYF(MY_WME));
+}
+
+int delete_table_proto_file(char *file_name)
+{
+  string new_path(file_name);
+  string file_ext = ".tabledefinition";
+
+  new_path.append(file_ext);
+  return my_delete(new_path.c_str(), MYF(0));
+}
+
 int create_table_proto_file(char *file_name,
                             const char *table_name,
                             HA_CREATE_INFO *create_info,

